@@ -1,6 +1,7 @@
 package Web::Scraper;
 use strict;
 use warnings;
+use 5.8.1;
 use Carp;
 use Scalar::Util qw(blessed);
 use List::Util qw(first);
@@ -10,7 +11,7 @@ use HTML::TreeBuilder::XPath;
 use HTML::Selector::XPath;
 use UNIVERSAL::require;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 sub import {
     my $class = shift;
@@ -70,7 +71,7 @@ sub scrape {
             my $encoding = first { defined $_ && Encode::find_encoding($_) } @encoding;
             $html = Encode::decode($encoding, $stuff->content);
         } else {
-            croak "GET $stuff failed: ", $stuff->status_line;
+            croak "GET " . $stuff->request->uri . " failed: ", $stuff->status_line;
         }
         $current ||= $stuff->request->uri;
     } elsif (blessed($stuff) && $stuff->isa('HTML::Element')) {
